Retrieve and assign the active working release
get_wrk_release.RdUtility for functions that need access to the currently configured
working release. The function fetches the wrk_release object from
the package .pipenv environment and assigns it into the caller's
frame under name (default: wrk_release). If no working release
is set, the function aborts with an informative message.
Usage
get_wrk_release(name = "wrk_release", verbose = getOption("pipfun.verbose"))Value
Invisibly returns NULL. The primary effect is that a variable
called name is assigned in the calling frame containing the working
release list (with release, identity, and ppp).
Examples
if (FALSE) { # \dontrun{
hello <- function() {
get_wrk_release()
invisible(wrk_release)
}
setup_working_release()
print(hello())
} # }