Initialize a new log
log_init.RdCreates a new named log as an empty piplog data.table to store log entries.
If the log already exists, it will be reset (unless overwrite = FALSE).
Details
The log is stored in the internal .piplogenv environment and can be
retrieved with log_get(), filtered with log_filter(), saved with
log_save(), or reset with log_reset().